@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import pytest
 
 
@@ -9,7 +8,7 @@ def setup(request):
     setup.finalize()
 
 
-class CostlySetup(object):
+class CostlySetup:
     def __init__(self):
         import time
 
