@@ -58,7 +58,7 @@ class TWMock:
     fullwidth = 80
 
 
-def test_excinfo_simple():
+def test_excinfo_simple() -> None:
     try:
         raise ValueError
     except ValueError:
@@ -66,6 +66,14 @@ def test_excinfo_simple():
     assert info.type == ValueError
 
 
+def test_excinfo_from_exc_info_simple():
+    try:
+        raise ValueError
+    except ValueError as e:
+        info = _pytest._code.ExceptionInfo.from_exc_info((type(e), e, e.__traceback__))
+    assert info.type == ValueError
+
+
 def test_excinfo_getstatement():
     def g():
         raise ValueError
@@ -370,7 +378,7 @@ def test_excinfo_no_python_sourcecode(tmpdir):
     excinfo = pytest.raises(ValueError, template.render, h=h)
     for item in excinfo.traceback:
         print(item)  # XXX: for some reason jinja.Template.render is printed in full
-        item.source  # shouldnt fail
+        item.source  # shouldn't fail
         if item.path.basename == "test.txt":
             assert str(item.source) == "{{ h()}}:"
 
@@ -589,7 +597,8 @@ raise ValueError()
 
     def test_repr_local_with_exception_in_class_property(self):
         class ExceptionWithBrokenClass(Exception):
-            @property
+            # Type ignored because it's bypassed intentionally.
+            @property  # type: ignore
             def __class__(self):
                 raise TypeError("boom!")
 
